@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-01-17'; # DATE
+our $DATE = '2022-01-21'; # DATE
 our $DIST = 'Acme-CPANModules-Parse-UnixCommands'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our $LIST = {
     summary => "Modules that parse output of Unix commands",
@@ -40,7 +40,7 @@ Acme::CPANModules::Parse::UnixCommands - Modules that parse output of Unix comma
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModules::Parse::UnixCommands (from Perl distribution Acme-CPANModules-Parse-UnixCommands), released on 2022-01-17.
+This document describes version 0.003 of Acme::CPANModules::Parse::UnixCommands (from Perl distribution Acme-CPANModules-Parse-UnixCommands), released on 2022-01-21.
 
 =head1 DESCRIPTION
 
@@ -48,47 +48,69 @@ This document describes version 0.002 of Acme::CPANModules::Parse::UnixCommands
 
 =over
 
-=item * L<Cisco::ShowIPRoute::Parser> - Parse Cisco "show ip route" command
+=item L<Cisco::ShowIPRoute::Parser>
+
+Parse Cisco "show ip route" command.
 
 Author: L<MARKPF|https://metacpan.org/author/MARKPF>
 
-=item * L<IPTables::Parse> - Parse iptables output
+=item L<IPTables::Parse>
+
+Parse iptables output.
 
 Author: L<MRASH|https://metacpan.org/author/MRASH>
 
-=item * L<Parse::IPCommand> - Parse linux "ip" command output
+=item L<Parse::IPCommand>
+
+Parse linux "ip" command output.
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Parse::Netstat::darwin> - Parse netstat output
+=item L<Parse::Netstat::darwin>
+
+Parse netstat output.
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Parse::Netstat::freebsd> - Parse netstat output
+=item L<Parse::Netstat::freebsd>
+
+Parse netstat output.
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Parse::Netstat::linux> - Parse netstat output
+=item L<Parse::Netstat::linux>
+
+Parse netstat output.
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Parse::Netstat::solaris> - Parse netstat output
+=item L<Parse::Netstat::solaris>
+
+Parse netstat output.
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Parse::Netstat> - Parse netstat output
+=item L<Parse::Netstat>
+
+Parse netstat output.
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Parse::Netstat::win32> - Parse netstat output
+=item L<Parse::Netstat::win32>
+
+Parse netstat output.
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<Parse::nm> - Parse nm output
+=item L<Parse::nm>
+
+Parse nm output.
 
 Author: L<DOLMEN|https://metacpan.org/author/DOLMEN>
 
-=item * L<Proc::ProcessTable> - Parse "ps ax" output
+=item L<Proc::ProcessTable>
+
+Parse "ps ax" output.
 
 Author: L<JWB|https://metacpan.org/author/JWB>
 
@@ -168,7 +190,7 @@ beyond that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
